@@ -14,6 +14,12 @@ import wrapt
 from .errors import ConfigError
 from .filters import FILTERS_BY_NAME
 
+if hasattr(re, "Pattern"):
+    from re import Pattern
+else:
+    import sre_compile
+    Pattern = type(sre_compile.compile("", 0))
+
 KNOWN_OPTIONS = []
 
 # define log levels
@@ -239,7 +245,7 @@ def validate_loglevel(val):
 
 
 def validate_regexp(value):
-    if isinstance(value, re.Pattern):
+    if isinstance(value, Pattern):
         return value
 
     if not isinstance(value, str):
